@@ -259,6 +259,11 @@ var xmlScenarios = []formatScenario{
 		input:    "<root>value<!-- comment-->anotherValue </root>",
 		expected: "root:\n    # comment\n    - value\n    - anotherValue\n",
 	},
+	{
+		skipDoc:  true,
+		input:    "<root><cats><cat>quick</cat><cat>soft</cat><!-- kitty_comment--><cat>squishy</cat></cats></root>",
+		expected: "root:\n    cats:\n        cat:\n            - quick\n            - soft\n            # kitty_comment\n\n            - squishy\n",
+	},
 	{
 		description:    "Parse xml: simple",
 		subdescription: "Notice how all the values are strings, see the next example on how you can fix that.",
